==> ump-0.8.3.2-src.tar.bz2: ump-0.8.3.2/src/main.h <==

/*
 *  Ump - Unnamed Math Program
 *  Copyright (c) 2003-2006 by Mattias Hultgren <mattias_hultgren@tele2.se>
 *
 *  See main.cpp
 */

#ifndef MAIN_H_
#define MAIN_H_

#include "vartypes.h"
#include "math2.h"
#include <string>

#define PRG_NAME    "Ump"
#define PRG_VERSION "v0.8.3.2"
#define PRG_DATE    "2003-2006"

const char *get_start_message(void);

extern void (*TEXTVIEW_FUNCTION)(const std::string &string);

extern std::string language_filename;

#ifndef NO_GTK
	void UMP_gtk_quit(void);


	extern const char *dialog_title_save_as, *dialog_title_open_file;

	extern const char *menu_file, *menu_file_new, *menu_file_open, *menu_file_save,
	                  *menu_file_save_as, *menu_file_close, *menu_file_quit;
	extern const char *menu_tools, *menu_tools_advanced, *menu_tools_editor,
	                  *menu_tools_simple, *menu_tools_graphtool, *menu_tools_matrixedit;
	extern const char *menu_about, *menu_pref;
  
	extern const char *button_ok, *button_cancel, *button_close;

	extern const char *edit_edit, *edit_edit_cut, *edit_edit_copy, *edit_edit_paste,
	                  *edit_edit_delete, *edit_edit_select_all;

	extern const char *filter_ump_files, *filter_all_files, *filter_picture_files,
	                  *filter_pcx_files, *filter_ppm_files;

	extern uint32 open_windows;
	const uint32 ADVANCED_WIN      = 1;
	const uint32 SIMPLE_WIN        = 2;
	const uint32 EDITOR_WIN        = 4;
	const uint32 GRAPHTOOL_WIN     = 8;
	const uint32 MATRIX_EDITOR_WIN = 16;

	extern std::string default_start_window;

#endif

void update_translation(std::string translation_filename, bool window_updating = true);

void hexstring_to_colorrgb(const char *str, picture_h::colorrgb &color) throw(error_obj);
void hexstring_to_colorrgbs(const char *str, Vector<picture_h::colorrgb> &colors) throw(error_obj);

extern Format format;
extern math::CodeBlock calc_function;

extern keyfile_io setup_file;

#endif

==> ump-0.8.4-src.tar.bz2: ump-0.8.4/src/main.h <==

/*
 *  Ump - Unnamed Math Program
 *  Copyright (c) 2003-2006 by Mattias Hultgren <mattias_hultgren@tele2.se>
 *
 *  See main.cpp
 */

#ifndef MAIN_H_
#define MAIN_H_

#include "vartypes.h"
#include "math2.h"
#include <string>

#define PRG_NAME    "Ump"
#define PRG_VERSION "v0.8.4"
#define PRG_DATE    "2003-2006"

const char *get_start_message(void);

extern void (*TEXTVIEW_FUNCTION)(const std::string &string);

extern std::string language_filename;

#ifndef NO_GTK
	void UMP_gtk_quit(void);


	extern const char *dialog_title_save_as, *dialog_title_open_file;

	extern const char *menu_file, *menu_file_new, *menu_file_open, *menu_file_save,
	                  *menu_file_save_as, *menu_file_close, *menu_file_quit;
	extern const char *menu_tools, *menu_tools_advanced, *menu_tools_editor,
	                  *menu_tools_simple, *menu_tools_graphtool, *menu_tools_matrixedit;
	extern const char *menu_about, *menu_pref;
  
	extern const char *button_ok, *button_cancel, *button_close;

	extern const char *edit_edit, *edit_edit_cut, *edit_edit_copy, *edit_edit_paste,
	                  *edit_edit_delete, *edit_edit_select_all;

	extern const char *filter_ump_files, *filter_all_files, *filter_picture_files,
	                  *filter_pcx_files, *filter_ppm_files;

	extern uint32 open_windows;
	const uint32 ADVANCED_WIN      = 1;
	const uint32 SIMPLE_WIN        = 2;
	const uint32 EDITOR_WIN        = 4;
	const uint32 GRAPHTOOL_WIN     = 8;
	const uint32 MATRIX_EDITOR_WIN = 16;

	extern std::string default_start_window;

#endif

void update_translation(std::string translation_filename, bool window_updating = true);

void hexstring_to_colorrgb(const char *str, picture_h::colorrgb &color) throw(error_obj);
void hexstring_to_colorrgbs(const char *str, Vector<picture_h::colorrgb> &colors) throw(error_obj);

extern Format format;
extern math::CodeBlock calc_function;

extern keyfile_io setup_file;

#endif
